# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: featurestore/core/OnlineApi.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='featurestore/core/OnlineApi.proto',
  package='featurestore.core',
  syntax='proto3',
  serialized_options=b'\n\030ai.h2o.featurestore.coreB\016OnlineApiProto',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!featurestore/core/OnlineApi.proto\x12\x11\x66\x65\x61turestore.core\"Y\n\x15OnlineRetrieveRequest\x12\x33\n\x06header\x18\x01 \x01(\x0b\x32#.featurestore.core.FeatureSetHeader\x12\x0b\n\x03key\x18\x02 \x01(\t\"%\n\x16OnlineRetrieveResponse\x12\x0b\n\x03row\x18\x01 \x01(\t\"X\n\x13OnlineIngestRequest\x12\x33\n\x06header\x18\x01 \x01(\x0b\x32#.featurestore.core.FeatureSetHeader\x12\x0c\n\x04rows\x18\x02 \x03(\t\"[\n\x10\x46\x65\x61tureSetHeader\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x02 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x03 \x01(\tB*\n\x18\x61i.h2o.featurestore.coreB\x0eOnlineApiProtob\x06proto3'
)




_ONLINERETRIEVEREQUEST = _descriptor.Descriptor(
  name='OnlineRetrieveRequest',
  full_name='featurestore.core.OnlineRetrieveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='featurestore.core.OnlineRetrieveRequest.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='featurestore.core.OnlineRetrieveRequest.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=145,
)


_ONLINERETRIEVERESPONSE = _descriptor.Descriptor(
  name='OnlineRetrieveResponse',
  full_name='featurestore.core.OnlineRetrieveResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='row', full_name='featurestore.core.OnlineRetrieveResponse.row', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=184,
)


_ONLINEINGESTREQUEST = _descriptor.Descriptor(
  name='OnlineIngestRequest',
  full_name='featurestore.core.OnlineIngestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='featurestore.core.OnlineIngestRequest.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rows', full_name='featurestore.core.OnlineIngestRequest.rows', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=186,
  serialized_end=274,
)


_FEATURESETHEADER = _descriptor.Descriptor(
  name='FeatureSetHeader',
  full_name='featurestore.core.FeatureSetHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='featurestore.core.FeatureSetHeader.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_id', full_name='featurestore.core.FeatureSetHeader.feature_set_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_version', full_name='featurestore.core.FeatureSetHeader.feature_set_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=367,
)

_ONLINERETRIEVEREQUEST.fields_by_name['header'].message_type = _FEATURESETHEADER
_ONLINEINGESTREQUEST.fields_by_name['header'].message_type = _FEATURESETHEADER
DESCRIPTOR.message_types_by_name['OnlineRetrieveRequest'] = _ONLINERETRIEVEREQUEST
DESCRIPTOR.message_types_by_name['OnlineRetrieveResponse'] = _ONLINERETRIEVERESPONSE
DESCRIPTOR.message_types_by_name['OnlineIngestRequest'] = _ONLINEINGESTREQUEST
DESCRIPTOR.message_types_by_name['FeatureSetHeader'] = _FEATURESETHEADER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OnlineRetrieveRequest = _reflection.GeneratedProtocolMessageType('OnlineRetrieveRequest', (_message.Message,), {
  'DESCRIPTOR' : _ONLINERETRIEVEREQUEST,
  '__module__' : 'featurestore.core.OnlineApi_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.OnlineRetrieveRequest)
  })
_sym_db.RegisterMessage(OnlineRetrieveRequest)

OnlineRetrieveResponse = _reflection.GeneratedProtocolMessageType('OnlineRetrieveResponse', (_message.Message,), {
  'DESCRIPTOR' : _ONLINERETRIEVERESPONSE,
  '__module__' : 'featurestore.core.OnlineApi_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.OnlineRetrieveResponse)
  })
_sym_db.RegisterMessage(OnlineRetrieveResponse)

OnlineIngestRequest = _reflection.GeneratedProtocolMessageType('OnlineIngestRequest', (_message.Message,), {
  'DESCRIPTOR' : _ONLINEINGESTREQUEST,
  '__module__' : 'featurestore.core.OnlineApi_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.OnlineIngestRequest)
  })
_sym_db.RegisterMessage(OnlineIngestRequest)

FeatureSetHeader = _reflection.GeneratedProtocolMessageType('FeatureSetHeader', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETHEADER,
  '__module__' : 'featurestore.core.OnlineApi_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.FeatureSetHeader)
  })
_sym_db.RegisterMessage(FeatureSetHeader)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
